@@ -68,7 +68,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 2 "conf/parser.y"
+#line 20 "conf/parser.y"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -79,7 +79,7 @@
 #include "conf.h"
 #include "config.h"
 
-#ifdef DEBUG
+#ifdef YYDEBUG
 #define log(args...) fprintf (stderr, args);
 #else
 #define log(args...)
@@ -90,11 +90,11 @@ extern int yylex (void);
 /* Defines needed for a pure reentrant parser/lexer.
    These are dsiabled for now due to failure to realize.
    #define YYLEX_PARAM   foo
- */
 #define YYPARSE_PARAM list
+ */
 
-#if 0 /* Not yet reentrant ... 
-       * reverting in the meantime for the sake of cygwin port 
+#if 0 /* Not yet reentrant ...
+       * reverting in the meantime for the sake of cygwin port
        */
 extern int yyget_lineno (void);
 #define yylineno      yyget_lineno ()
@@ -110,14 +110,17 @@ int yyerror (char *s)
   return -1;
 }
 
-/* XXX - Add filename to syntax error message. */
+/* XXX - Add filename to syntax error message.
+  Use NULL, we are not yet reentrant.
+  otherwise use: if (conf_set_value ((param_t *)list, key, value))
+*/
+
 #define conf_set(key,value)				\
-  if (conf_set_value ((param_t *)list, key, value))	\
-    fprintf (stderr,					\
-	     "Error on line %d in config file, "	\
-	     "%s is not a valid identifier.\n",		\
-	     yylineno, key)
- 
+  if (conf_set_value ((param_t *)NULL, key, value))     \
+    log ("Error on line %d in config file, "		\
+	 "%s is not a valid identifier.\n",		\
+	 yylineno, key)
+
 
 
 /* Enabling traces.  */
@@ -134,12 +137,12 @@ int yyerror (char *s)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 55 "conf/parser.y"
+#line 76 "conf/parser.y"
 typedef union YYSTYPE {
 	char *str;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 143 "parser.c"
+#line 146 "parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -151,7 +154,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 155 "parser.c"
+#line 158 "parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -318,7 +321,7 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    64,    64,    65,    68,    69,    72,    74
+       0,    85,    85,    86,    89,    90,    93,    95
 };
 #endif
 
@@ -1016,13 +1019,13 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 72 "conf/parser.y"
+#line 93 "conf/parser.y"
     {log ("\nBison(ID:%s)(ARG:%s)", yyvsp[-2].str, yyvsp[0].str);
                                  conf_set (yyvsp[-2].str, yyvsp[0].str);}
     break;
 
   case 7:
-#line 74 "conf/parser.y"
+#line 95 "conf/parser.y"
     {log ("%s(%s)\n", yyvsp[-1].str, yyvsp[0].str);
                                  conf_set (yyvsp[-1].str, yyvsp[0].str);}
     break;
@@ -1031,7 +1034,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1035 "parser.c"
+#line 1038 "parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1225,7 +1228,6 @@ yyreturn:
 }
 
 
-#line 78 "conf/parser.y"
-
+#line 99 "conf/parser.y"
 
 
