@@ -1,7 +1,7 @@
 /* daemon.c - Holds the auto-login daemon and its code.
  *
- * Copyright (c) 2001 Jakob "kuba" Stasilowicz <kuba@unix.se>
- * Copyright (c) 2003 Joachim Nilsson <joachim.nilsson@vmlinux.org>
+ * Copyright (c) 2001 Jakob "kuba" Stasilowicz <kuba()unix!se>
+ * Copyright (c) 2003,2004 Joachim Nilsson <joachim!nilsson()member!fsf!org>
  *
  * qADSL is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -87,7 +87,7 @@ daemonize (void)
       signal (SIGTSTP, SIG_IGN);
 #endif
       /* Become session leader and group process leader
-       * with no controlling terminal 
+       * with no controlling terminal
        */
       setsid ();
     }
@@ -110,32 +110,43 @@ daemonize (void)
 static void
 daemon_sighandler (int signal)
 {
-  write_log ("%s[%d]: Got signal(%d), quiting!\n", 
-             PACKAGE_NAME, getpid (), signal);
+  /* We quit on everything but HUP */
+  if (SIGHUP != signal)
+    {
+      write_logfile (LOG_INFO, "Got signal(%d), quitting.", signal);
 
-  exit (0);
+      exit (0);
+    }
+  else
+    {
+      write_logfile (LOG_INFO, "Got signal(%d), forcing relogin.", signal);
+    }
 }
 
 
 
 /**
  * autologin_daemon - This is what keeps us going
- * 
+ *
  * This thread function is the one responsible for keeping the
- * connection open. This function is called when a properly
+ * connection open.  This function is called when a properly
  * daemonized thread is started.
+ *
+ * XXX - Add nifty feature to log "Periodic status report: qadsl is CONNECTED"
+ * and "NOT CONNECTED".  This message should be logged every 60 minutes and
+ * could easily be made up from a multiple of the DELAY.
  */
 
 void
-daemon_thread (config_data_t *config)
+daemon_thread (config_data_t *config, int verbose)
 {
-  int result;
+  int result, slept, latched_logged_in = -1;
   unsigned int timeout = 60 * config->daemon_delay;
   pid_t mypid = getpid ();
 
-  write_log ("qADSL daemon started, pid: %d\n", mypid);
+  signal (SIGTERM, daemon_sighandler);
+  signal (SIGHUP, daemon_sighandler);
 
-  (void) signal (SIGTERM, daemon_sighandler);
   result = lock_create (&config->pid_file, mypid);
   if (result)
     {
@@ -143,65 +154,64 @@ daemon_thread (config_data_t *config)
        * daemon to start since there is no way (other than ps)
        * to communicate the PID to the outside world.
        */
-      write_log ("Cannot write PID(%d) to file, %s - %s\n"
-		 "Aborting daemon - cannot communicate PID to outside world.\n",
-                 (int)mypid, config->pid_file, strerror (errno));
+      ERROR ("Cannot write PID(%d) to file, %s: %s",
+             (int)mypid, config->pid_file, strerror (errno));
+      ERROR ("Aborting daemon - cannot communicate PID to outside world.");
+
       /* Bye bye */
       return;
     }
+  else
+    {
+      write_logfile (LOG_INFO, "Keep-alive daemon started, pid: %d", mypid);
+    }
 
   while (1)
     {
-      /* Close all connections before going to sleep. */
-      close (config->sockfd);
+      if (latched_logged_in != config->logged_in)
+        {
+          write_logfile (LOG_INFO, "Login %s", config->logged_in ? "successful." : "FAILED!");
+        }
+      latched_logged_in = config->logged_in;
 
       /* Now, sleep before we reconnect and check status. */
-      sleep (timeout);
+      slept = sleep (timeout);
 
-      config->sockfd = open_server (config->login_server, config->server_port, 0);
-      if (-1 == config->sockfd)
-        {
-          write_log ("Failed to contact server.");
-          continue;
-        }
-      
       /* The "ping" daemon only reads /sd/init */
-      result = pre_login (config, 0);
-      if (result)
+      http_pre_login (config, verbose);
+
+      /* The login daemon also tries to login, but only if
+       * the call to http_pre_login() did *not* bring up
+       * the "redirect page".
+       */
+      if (config->daemon_type && !config->logged_in)
         {
-          write_log ("%s: Failed to bring up login page.\n", PACKAGE_NAME);
-          continue;
+          LOG ("Daemon logging in again.");
+          http_do_login (config, verbose);
         }
-      /* Test if we're logged in already. */
-      if (strstr (config->get_msg, config->logged_in_string))
+
+      /* This stuff added for verbosity */
+      if (slept > 0)            /* Awoken by SIGHUP */
         {
-          config->logged_in = 1;
+          if (config->logged_in)
+            {
+              write_logfile (LOG_INFO, "Forced relogin successful.");
+            }
+          else
+            {
+              write_logfile (LOG_INFO, "Forced relogin FAILED!");
+            }
         }
-      
-      /* The login daemon also tries to login. */
-      if (config->daemon_type && !(config->logged_in))
+      else
         {
-          log_login (config, 0);
+          LOG ("Periodic relogin %s.", config->logged_in ? "OK" : "FAILED");
         }
     }
 }
 
-
-/**
- * daemon_kill - Terminates the login daemon.
- * @pid: Process ID to kill.
- *
- * This function sends SIGTERM to gracefully let the
- * login daemon process .. exit.
- *
- * Returns: The result of kill().
+/* Local Variables:
+ * mode: C;
+ * c-file-style: gnu;
+ * indent-tabs-mode: nil;
+ * End:
  */
-
-int
-daemon_kill (pid_t pid)
-{
-  return kill (pid, SIGTERM);
-}
-
- 
-
